#Spécification du répertoire de travail
setwd("/Users/Salim/Desktop/Cartes")

#Chargement des librairies utiles
library(rgdal)
library(plotrix)
library(classInt)

##################
## DEPARTEMENTS ##
##################


#Lecture de la carte
departements <- readOGR(dsn="departements-geofla",layer="DEPARTEMENT")

#Variables présentes
names(departements)

#Lecture des données statistiques
donnees <- read.table("donneesdep.csv",sep=";",header=TRUE,dec=",")

#Fusion de la carte avec les données
departements <- merge(departements,donnees,by.x="CODE_DEPT",by.y="INSEE")

#Calcul d'une nouvelle variable
departements$densite <- departements$population/departements$superficie

#Définition e l'Échelle de couleurs
col <- findColours(classIntervals(
  round(departements$densite), 10, style="quantile"),
  smoothColors("white",10,"blue"))

#Définition de la Légende
leg <- findColours(classIntervals(
  round(departements$densite), 5, style="quantile"),
  smoothColors("white",10,"blue"),
  under="moins de", over="plus de", between="–",
  cutlabels=FALSE)

#Affichage de la carte
plot(departements,col=col,border="black")

#Affichage de la Légende
legend(60000,6387500,fill=attr(leg, "palette"),
       legend=names(attr(leg,"table")),
       title = "Densité en hab/km² :",cex=0.6)

##############
## COMMUNES ##
##############

#Lecture de la carte
communes <- readOGR(dsn="communes-geofla",layer="COMMUNE")

#Variables présentes
names(communes)

#Lecture des données statistiques
donnees <- read.table("revenus-communes.csv",sep=";",header=TRUE,dec=",") 

#Fusion de la carte avec les données
revenus <- merge(communes,donnees,by.x="INSEE_COM",by.y="CODGEO")

#Définition e l'Échelle de couleurs
col <- findColours(classIntervals(
  revenus$MED14, 100, style="pretty"),
  smoothColors("#fee6ce",98,"#e6550d"))
col[is.na(revenus$MED14)] <- "#DDDDDD"

#Définition de la Légende
leg <- findColours(classIntervals(
  round(revenus$MED14), 7, style="pretty"),
  smoothColors("#fee6ce",5,"#e6550d"),
  under="moins de", over="plus de", between="–",
  cutlabels=FALSE)

#Affichage de la carte
plot(revenus,col=col,border=col,lwd=.1)

#Affichage de la Légende
legend(40000,6387500,fill=attr(leg, "palette"),
       legend=names(attr(leg,"table")),
       title = "Revenu médian en EUR :",cex=0.6,bty="n")

#############
# BRETAGNE ##
#############

bzh <- communes[communes$NOM_REG=="BRETAGNE",]

#Lecture des données statistiques
donnees <- read.table("revenus-communes.csv",sep=";",header=TRUE,dec=",") 

#Fusion de la carte avec les données
revenus <- merge(bzh,donnees,by.x="INSEE_COM",by.y="CODGEO")

#Définition e l'Échelle de couleurs
col <- findColours(classIntervals(
  revenus$MED14, 100, style="pretty"),
  smoothColors("#fee6ce",98,"#e6550d"))
col[is.na(revenus$MED14)] <- "#DDDDDD"

#Définition de la Légende
leg <- findColours(classIntervals(
  round(revenus$MED14), 7, style="pretty"),
  smoothColors("#fee6ce",5,"#e6550d"),
  under="moins de", over="plus de", between="–",
  cutlabels=FALSE)

#Affichage de la carte
plot(revenus,col=col,border=col,lwd=.1)


#Affichage de la Légende

legend(min(revenus$X_CENTROID)*0.995,min(revenus$Y_CENTROID)*1.005,fill=attr(leg, "palette"),
       legend=names(attr(leg,"table")),
       title = "Revenu médian en EUR :",cex=0.6,bty="n")


##########
# MONDE ##
##########

pays   <- readOGR(dsn="pays-naturalearth",layer="ne_50m_admin_0_countries")

names(pays)

levels(pays$ISO_A3) <- c(levels(pays$ISO_A3),"NOR","FRA")
pays$ISO_A3[pays$ISO_A3=="-99"] <- c("-99","NOR","-99","FRA","-99","-99","-99","-99")

# Données

donnees <- read.table("co2gdp.csv",header=TRUE,sep=";",dec=",")

head(donnees)

# Conversion du GDP en valeur numérique
# donnees$gdp <- as.numeric(levels(donnees$gdp))[donnees$gdp]

donnees$ratio <- donnees$co2

# Merge
pays <- merge(pays, donnees, by.x="ISO_A3", by.y="Code")

# Génération de l'échelle de couleurs et affectation
col <- findColours(classIntervals(pays$ratio, 100, style="quantile"),
                   smoothColors("#fee6ce",98,"#e6550d"))

# Affectation d'un gris clair pour les données manquantes
col[is.na(pays$ratio)] <- "#DDDDDD"

# Génération de la légende
leg <- findColours(classIntervals(round(pays$ratio,3), 7, style="quantile"),
                   smoothColors("#fee6ce",5,"#e6550d"),
                   under="less than", over="more than", between="–", cutlabels=FALSE)

# Projection en Winkel Tripel
pays   <- spTransform(pays,CRS("+proj=wintri"))

# Affichage de la carte
plot(pays,  col=col, border=col,lwd=.8)

# Affichage de la légende
legend(-15000000,-3000000,fill=attr(leg, "palette"),
       legend=gsub("\\.", ",", names(attr(leg,"table"))),
       title = "CO2 emissions (kt) :",cex=0.6,bty="n")


